@@ -1,5 +1,5 @@
+from ecsclient import schemas
 from tests import functional
-from tests.functional import schemas
 
 
 class TestLicense(functional.BaseTestCase):
